@@ -5,7 +5,7 @@
     Copyright (C) 2002-2005 Nasca Octavian Paul
     Copyright 2009-2011, Alan Calvert
     Copyright 2013, Nikita Zlobin
-    Copyright 2014-2015, Will Godfrey & others
+    Copyright 2014-2016, Will Godfrey & others
 
     This file is part of yoshimi, which is free software: you can redistribute
     it and/or modify it under the terms of the GNU Library General Public
@@ -48,9 +48,9 @@ using namespace std;
 #include "Misc/SynthEngine.h"
 #include "Misc/Config.h"
 #include "MasterUI.h"
+#include "ConfBuild.cpp"
 
 extern void mainRegisterAudioPort(SynthEngine *s, int portnum);
-const unsigned short Config::MaxParamsHistory = 25;
 
 static char prog_doc[] =
     "Yoshimi " YOSHIMI_VERSION ", a derivative of ZynAddSubFX - "
@@ -58,8 +58,8 @@ static char prog_doc[] =
     "Copyright 2009-2011 Alan Calvert, "
     "Copyright 20012-2013 Jeremy Jongepier and others, "
     "Copyright 20014-2016 Will Godfrey and others";
-
-const char* argp_program_version = "Yoshimi " YOSHIMI_VERSION;
+string argline = "Yoshimi " + (string) YOSHIMI_VERSION + "\nBuild Number " + to_string(BUILD_NUMBER);
+const char* argp_program_version = argline.c_str();
 
 static struct argp_option cmd_options[] = {
     {"alsa-audio",        'A',  "<device>",   1,  "use alsa audio output" },
@@ -90,12 +90,14 @@ static struct argp_option cmd_options[] = {
 
 Config::Config(SynthEngine *_synth, int argc, char **argv) :
     restoreState(false),
+    stateChanged(false),
     restoreJackSession(false),
     Samplerate(48000),
     Buffersize(256),
     Oscilsize(512),
     runSynth(true),
     showGui(true),
+    showSplash(true),
     showCLI(true),
     VirKeybLayout(1),
     audioEngine(DEFAULT_AUDIO),
@@ -105,7 +107,7 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     jackServer("default"),
     jackMidiDevice("default"),
     startJack(false),
-    connectJackaudio(false),
+    connectJackaudio(true),
     alsaAudioDevice("default"),
     alsaMidiDevice("default"),
     GzipCompression(3),
@@ -113,7 +115,8 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     checksynthengines(1),
     xmlType(0),
     EnableProgChange(1), // default will be inverted
-    consoleMenuItem(0),
+    toConsole(0),
+    hideErrors(0),
     logXMLheaders(0),
     configChanged(false),
     rtprio(50),
@@ -121,6 +124,7 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     midi_bank_C(32),
     midi_upper_voice_C(128),
     enable_part_on_voice_load(1),
+    ignoreResetCCs(false),
     monitorCCin(false),
     single_row_panel(1),
     NumAvailableParts(NUM_MIDI_CHANNELS),
@@ -128,12 +132,10 @@ Config::Config(SynthEngine *_synth, int argc, char **argv) :
     nrpnL(127),
     nrpnH(127),
     nrpnActive(false),
-
     deadObjects(NULL),
-    nextHistoryIndex(numeric_limits<unsigned int>::max()),
     sigIntActive(0),
-    ladi1IntActive(0),    
-    sse_level(0),    
+    ladi1IntActive(0),
+    sse_level(0),
     programcommand(string("yoshimi")),
     synth(_synth),
     bRuntimeSetupCompleted(false)
@@ -161,14 +163,23 @@ bool Config::Setup(int argc, char **argv)
         return false;
 
     if(synth->getIsLV2Plugin()) //skip further setup for lv2 plugin instance.
+    {
+        /*
+         * These are needed here now, as for stand-alone they have
+         * been moved to main to give the users the impression of
+         * a faster startup, and reduce the likelyhood of thinking
+         * they failed and trying to start again.
+         */
+        synth->installBanks(synth->getUniqueId());
+        synth->loadHistory();
         return true;
+    }
     switch (audioEngine)
     {
         case alsa_audio:
-        {
             audioDevice = string(alsaAudioDevice);
             break;
-        }
+
         case jack_audio:
             audioDevice = string(jackServer);
             break;
@@ -184,9 +195,11 @@ bool Config::Setup(int argc, char **argv)
         case jack_midi:
             midiDevice = string(jackMidiDevice);
             break;
+
         case alsa_midi:
             midiDevice = string(alsaMidiDevice);
             break;
+
         case no_midi:
         default:
             midiDevice.clear();
@@ -195,6 +208,10 @@ bool Config::Setup(int argc, char **argv)
     if (!midiDevice.size())
         midiDevice = "";
     loadCmdArgs(argc, argv);
+    Oscilsize = nearestPowerOf2(Oscilsize, MAX_AD_HARMONICS * 2, 16384);
+    Buffersize = nearestPowerOf2(Buffersize, 16, 1024);
+    //Log(asString(Oscilsize));
+    //Log(asString(Buffersize));
     if (restoreState)
     {
         char * fp;
@@ -212,7 +229,20 @@ bool Config::Setup(int argc, char **argv)
             return false;
         }
         Log(StateFile);
-    }    
+        restoreSessionData(StateFile, true);
+        /* This needs improving!
+         * There is a single state file that contains both startup config
+         * data that must be set early, and runtime data that must be set
+         * after synth has been initialised.
+         *
+         * Currently we open it here and fetch just the startup data, then
+         * reopen it in synth and fetch all the data (including the startup
+         * again).
+         *
+         * This is further complicated because the same functions are
+         * being used by jack session.
+         */
+    }
     return true;
 }
 
@@ -236,49 +266,6 @@ void Config::flushLog(void)
 }
 
 
-string Config::addParamHistory(string file)
-{
-    if (!file.empty())
-    {
-        unsigned int name_start = file.rfind("/");
-        unsigned int name_end = file.rfind(".xmz");
-        if (name_start != string::npos && name_end != string::npos
-            && (name_start - 1) < name_end)
-        {
-            HistoryListItem item;
-            item.name = file.substr(name_start + 1, name_end - name_start - 1);
-            item.file = file;
-            item.index = nextHistoryIndex--;
-            itx = ParamsHistory.begin();
-            for (unsigned int i = 0; i < ParamsHistory.size(); ++i, ++itx)
-                if (ParamsHistory.at(i).sameFile(file))
-                    ParamsHistory.erase(itx);
-            ParamsHistory.insert(ParamsHistory.begin(), item);
-            if (ParamsHistory.size() > MaxParamsHistory)
-            {
-                itx = ParamsHistory.end();
-                ParamsHistory.erase(--itx);
-            }
-            return (CurrentXMZ = item.name);
-        }
-        else
-            Log("Invalid param file proffered to history:" + file);
-    }
-    return string();
-}
-
-
-string Config::historyFilename(int index)
-{
-    if (index > 0 && index <= (int)ParamsHistory.size())
-    {
-        itx = ParamsHistory.begin();
-        for (int i = index; i > 0; ++itx, --i) ;
-        return itx->file;
-    }
-    return string();
-}
-
 bool Config::showQuestionOrCmdWarning(string guiQuestion, string cmdLineWarning, bool bForceCmdLinePositive)
 {
     bool bRet = false;
@@ -303,33 +290,43 @@ string Config::testCCvalue(int cc)
         case 1:
             result = "mod wheel";
             break;
+
         case 10:
             result = "panning";
             break;
+
         case 11:
             result = "expression";
             break;
+
         case 38:
             result = "data lsb";
             break;
+
         case 71:
             result = "filter Q";
             break;
+
         case 74:
             result = "filter cutoff";
             break;
+
         case 75:
             result = "bandwidth";
             break;
+
         case 76:
             result = "FM amplitude";
             break;
+
         case 77:
             result = "resonance centre";
             break;
+
         case 78:
             result = "resonance bandwidth";
             break;
+
         default:
             result = masterCCtest(cc);
     }
@@ -345,39 +342,51 @@ string Config::masterCCtest(int cc)
          case 6:
             result = "data msb";
             break;
+
         case 7:
             result = "volume";
             break;
+
         case 38:
             result = "data lsb";
             break;
+
         case 64:
             result = "sustain pedal";
             break;
+
         case 65:
             result = "portamento";
             break;
+
         case 96:
             result = "data increment";
             break;
+
         case 97:
             result = "data decrement";
             break;
+
         case 98:
             result = "NRPN lsb";
             break;
+
         case 99:
             result = "NRPN msb";
             break;
+
         case 120:
             result = "all sounds off";
             break;
+
         case 121:
             result = "reset all controllers";
             break;
+
         case 123:
             result = "all notes off";
             break;
+
         default:
         {
             if (cc < 128) // don't compare with 'disabled' state
@@ -397,7 +406,7 @@ string Config::masterCCtest(int cc)
 
 void Config::clearPresetsDirlist(void)
 {
-    for (int i = 0; i < MAX_PRESETS; ++i)
+    for (int i = 0; i < MAX_PRESET_DIRS; ++i)
         presetsDirlist[i].clear();
 }
 
@@ -421,7 +430,7 @@ bool Config::loadConfig(void)
     }
     string yoshimi = "/"; // for some reason it doesn't
     yoshimi += YOSHIMI; // like these as one line here
-    
+
     if (synth->getUniqueId() > 0)
         yoshimi += ("-" + asString(synth->getUniqueId()));
     string presetDir = ConfigDir + "/presets";
@@ -439,8 +448,8 @@ bool Config::loadConfig(void)
     if (!isRegFile(resConfigFile) && !isRegFile(ConfigFile))
     {
         Log("ConfigFile " + resConfigFile + " not found, will use default settings");
+        defaultPresets();
         configChanged = true; // give the user the choice
-        //saveConfig();
     }
     else
     {
@@ -450,7 +459,7 @@ bool Config::loadConfig(void)
         else
         {
             if (!xml->loadXMLfile(resConfigFile))
-            {                
+            {
                 if((synth->getUniqueId() > 0) && (!xml->loadXMLfile(ConfigFile)))
                 {
                     Log("loadConfig loadXMLfile failed");
@@ -467,6 +476,30 @@ bool Config::loadConfig(void)
 }
 
 
+void Config::defaultPresets(void)
+{
+    string presetdirs[]  = {
+        "/usr/share/yoshimi/presets",
+        "/usr/local/share/yoshimi/presets",
+        "/usr/share/zynaddsubfx/presets",
+        "/usr/local/share/zynaddsubfx/presets",
+        string(getenv("HOME")) + "/.config/yoshimi/presets",
+        localPath("/presets"),
+        "end"
+    };
+    int i = 0;
+    while (presetdirs[i] != "end")
+    {
+        if (isDirectory(presetdirs[i]))
+        {
+            Log(presetdirs[i], 2);
+            presetsDirlist[i] = presetdirs[i];
+        }
+        ++ i;
+    }
+}
+
+
 bool Config::extractConfigData(XMLwrapper *xml)
 {
     if (!xml)
@@ -479,56 +512,48 @@ bool Config::extractConfigData(XMLwrapper *xml)
         Log("extractConfigData, no CONFIGURATION branch");
         return false;
     }
-    Samplerate = xml->getpar("sample_rate", Samplerate, 44100, 96000);
-    Buffersize = xml->getpar("sound_buffer_size", Buffersize, 16, 1024);
-    Oscilsize = xml->getpar("oscil_size", Oscilsize,
-                                        MAX_AD_HARMONICS * 2, 131072);
     GzipCompression = xml->getpar("gzip_compression", GzipCompression, 0, 9);
-    Interpolation = xml->getpar("interpolation", Interpolation, 0, 1);
-    checksynthengines = xml->getpar("check_pad_synth", checksynthengines, 0, 1);
-    EnableProgChange = 1 - xml->getpar("ignore_program_change", EnableProgChange, 0, 1); // inverted for Zyn compatibility
-    consoleMenuItem = xml->getpar("reports_destination", consoleMenuItem, 0, 1);
+    showGui = xml->getpar("enable_gui", showGui, 0, 1);
+    showSplash = xml->getpar("enable_splash", showSplash, 0, 1);
+    showCLI = xml->getpar("enable_CLI", showCLI, 0, 1);
+    single_row_panel = xml->getpar("single_row_panel", single_row_panel, 0, 1);
+    toConsole = xml->getpar("reports_destination", toConsole, 0, 1);
+    hideErrors = xml->getpar("hide_system_errors", hideErrors, 0, 1);
     logXMLheaders = xml->getpar("report_XMLheaders", logXMLheaders, 0, 1);
     VirKeybLayout = xml->getpar("virtual_keyboard_layout", VirKeybLayout, 0, 10);
 
-    audioEngine = (audio_drivers)xml->getpar("audio_engine", audioEngine, no_audio, alsa_audio);
-    midiEngine = (midi_drivers)xml->getpar("midi_engine", midiEngine, no_midi, alsa_midi);
-    showGui = xml->getpar("enable_gui", showGui, 0, 1);
-    showCLI = xml->getpar("enable_CLI", showCLI, 0, 1);
-
+    Samplerate = xml->getpar("sample_rate", Samplerate, 44100, 192000);
+    Buffersize = xml->getpar("sound_buffer_size", Buffersize, 16, 1024);
+    Oscilsize = xml->getpar("oscil_size", Oscilsize, MAX_AD_HARMONICS * 2, 16384);
 
     // get preset dirs
     int count = 0;
-    for (int i = 0; i < MAX_PRESETS; ++i)
+    bool found = false;
+    for (int i = 0; i < MAX_PRESET_DIRS; ++i)
     {
         if (xml->enterbranch("PRESETSROOT", i))
         {
             string dir = xml->getparstr("presets_root");
             if (isDirectory(dir))
+            {
                 presetsDirlist[count++] = dir;
+                found = true;
+            }
             xml->exitbranch();
         }
     }
-    if (!count)
+    if (!found)
     {
-        string presetdirs[]  = {
-            "/usr/share/yoshimi/presets",
-            "/usr/local/share/yoshimi/presets",
-            "/usr/share/zynaddsubfx/presets",
-            "/usr/local/share/zynaddsubfx/presets",
-            string(getenv("HOME")) + "/.config/yoshimi/presets",
-            localPath("/presets"),
-            "end"
-        };
-        int i = 0;
-        while (presetdirs[i] != "end")
-        {
-            if (isDirectory(presetdirs[i]))
-                presetsDirlist[count++] = presetdirs[i];
-            ++ i;
-        }
+        defaultPresets();
+        configChanged = true; // give the user the choice
     }
-    
+
+    Interpolation = xml->getpar("interpolation", Interpolation, 0, 1);
+
+    // engines
+    audioEngine = (audio_drivers)xml->getpar("audio_engine", audioEngine, no_audio, alsa_audio);
+    midiEngine = (midi_drivers)xml->getpar("midi_engine", midiEngine, no_midi, alsa_midi);
+
     // alsa settings
     alsaAudioDevice = xml->getparstr("linux_alsa_audio_dev");
     alsaMidiDevice = xml->getparstr("linux_alsa_midi_dev");
@@ -536,35 +561,19 @@ bool Config::extractConfigData(XMLwrapper *xml)
     // jack settings
     jackServer = xml->getparstr("linux_jack_server");
     jackMidiDevice = xml->getparstr("linux_jack_midi_dev");
+    connectJackaudio = xml->getpar("connect_jack_audio", connectJackaudio, 0, 1);
 
     // midi options
     midi_bank_root = xml->getpar("midi_bank_root", midi_bank_root, 0, 128);
     midi_bank_C = xml->getpar("midi_bank_C", midi_bank_C, 0, 128);
     midi_upper_voice_C = xml->getpar("midi_upper_voice_C", midi_upper_voice_C, 0, 128);
+    EnableProgChange = 1 - xml->getpar("ignore_program_change", EnableProgChange, 0, 1); // inverted for Zyn compatibility
     enable_part_on_voice_load = xml->getpar("enable_part_on_voice_load", enable_part_on_voice_load, 0, 1);
-//    consoleMenuItem = xml->getpar("enable_console_window", consoleMenuItem, 0, 1);
-    single_row_panel = xml->getpar("single_row_panel", single_row_panel, 0, 1);
+    ignoreResetCCs = xml->getpar("ignore_reset_all_CCs",ignoreResetCCs,0, 1);
 
-    if (xml->enterbranch("XMZ_HISTORY"))
-    {
-        int hist_size = xml->getpar("history_size", 0, 0, MaxParamsHistory);
-        string xmz;
-        for (int i = 0; i < hist_size; ++i)
-        {
-            if (xml->enterbranch("XMZ_FILE", i))
-            {
-                xmz = xml->getparstr("xmz_file");
-                if (xmz.size() && isRegFile(xmz))
-                    addParamHistory(xmz);
-                xml->exitbranch();
-            }
-        }
-        xml->exitbranch();
-    }
+    //misc
+    checksynthengines = xml->getpar("check_pad_synth", checksynthengines, 0, 1);
 
-    // get bank dirs
-    //synth->getBankRef().parseConfigFile(xml);
-    
     xml->exitbranch(); // CONFIGURATION
     return true;
 }
@@ -580,16 +589,12 @@ void Config::saveConfig(void)
         return;
     }
     addConfigXML(xmltree);
-    unsigned int tmp = GzipCompression;
-    GzipCompression = 0;
-
     string resConfigFile = ConfigFile;
 
     if (xmltree->saveXMLfile(resConfigFile))
         configChanged = false;
     else
         Log("Failed to save config to " + resConfigFile);
-    GzipCompression = tmp;
 
     delete xmltree;
 }
@@ -598,23 +603,21 @@ void Config::saveConfig(void)
 void Config::addConfigXML(XMLwrapper *xmltree)
 {
     xmltree->beginbranch("CONFIGURATION");
+    xmltree->addpar("gzip_compression", GzipCompression);
+    xmltree->addpar("enable_gui", synth->getRuntime().showGui);
+    xmltree->addpar("enable_splash", synth->getRuntime().showSplash);
+    xmltree->addpar("enable_CLI", synth->getRuntime().showCLI);
+    xmltree->addpar("single_row_panel", single_row_panel);
+    xmltree->addpar("reports_destination", toConsole);
+    xmltree->addpar("hide_system_errors", hideErrors);
+    xmltree->addpar("report_XMLheaders", logXMLheaders);
+    xmltree->addpar("virtual_keyboard_layout", VirKeybLayout);
 
     xmltree->addpar("sample_rate", Samplerate);
     xmltree->addpar("sound_buffer_size", Buffersize);
     xmltree->addpar("oscil_size", Oscilsize);
 
-    xmltree->addpar("gzip_compression", GzipCompression);
-    xmltree->addpar("check_pad_synth", checksynthengines);
-    xmltree->addpar("ignore_program_change", (1 - EnableProgChange));
-    xmltree->addpar("reports_destination", consoleMenuItem);
-    xmltree->addpar("report_XMLheaders", logXMLheaders);
-    xmltree->addpar("virtual_keyboard_layout", VirKeybLayout);
-    xmltree->addpar("audio_engine", synth->getRuntime().audioEngine);
-    xmltree->addpar("midi_engine", synth->getRuntime().midiEngine);
-    xmltree->addpar("enable_gui", synth->getRuntime().showGui);
-    xmltree->addpar("enable_CLI", synth->getRuntime().showCLI);
-
-    for (int i = 0; i < MAX_PRESETS; ++i)
+    for (int i = 0; i < MAX_PRESET_DIRS; ++i)
         if (presetsDirlist[i].size())
         {
             xmltree->beginbranch("PRESETSROOT",i);
@@ -623,36 +626,24 @@ void Config::addConfigXML(XMLwrapper *xmltree)
         }
 
     xmltree->addpar("interpolation", Interpolation);
-    
+
+    xmltree->addpar("audio_engine", synth->getRuntime().audioEngine);
+    xmltree->addpar("midi_engine", synth->getRuntime().midiEngine);
+
     xmltree->addparstr("linux_alsa_audio_dev", alsaAudioDevice);
     xmltree->addparstr("linux_alsa_midi_dev", alsaMidiDevice);
+
     xmltree->addparstr("linux_jack_server", jackServer);
     xmltree->addparstr("linux_jack_midi_dev", jackMidiDevice);
+    xmltree->addpar("connect_jack_audio", connectJackaudio);
 
     xmltree->addpar("midi_bank_root", midi_bank_root);
     xmltree->addpar("midi_bank_C", midi_bank_C);
     xmltree->addpar("midi_upper_voice_C", midi_upper_voice_C);
+    xmltree->addpar("ignore_program_change", (1 - EnableProgChange));
     xmltree->addpar("enable_part_on_voice_load", enable_part_on_voice_load);
-//    xmltree->addpar("enable_console_window", consoleMenuItem);
-    xmltree->addpar("single_row_panel", single_row_panel);
-
-    // Parameters history
-    if (ParamsHistory.size())
-    {
-        xmltree->beginbranch("XMZ_HISTORY");
-        xmltree->addpar("history_size", ParamsHistory.size());
-        deque<HistoryListItem>::reverse_iterator rx = ParamsHistory.rbegin();
-        unsigned int count = 0;
-        for (int x = 0; rx != ParamsHistory.rend() && count <= MaxParamsHistory; ++rx, ++x)
-        {
-            xmltree->beginbranch("XMZ_FILE", x);
-            xmltree->addparstr("xmz_file", rx->file);
-            xmltree->endbranch();
-        }
-        xmltree->endbranch();
-    }
-    //synth->getBankRef().saveToConfigFile(xmltree);
-
+    xmltree->addpar("ignore_reset_all_CCs",ignoreResetCCs);
+    xmltree->addpar("check_pad_synth", checksynthengines);
     xmltree->endbranch(); // CONFIGURATION
 }
 
@@ -666,7 +657,7 @@ void Config::saveSessionData(string savefile)
     XMLwrapper *xmltree = new XMLwrapper(synth);
     if (!xmltree)
     {
-        Log("saveSessionData failed xmltree allocation", true);
+        Log("saveSessionData failed xmltree allocation", 1);
         return;
     }
     addConfigXML(xmltree);
@@ -675,11 +666,11 @@ void Config::saveSessionData(string savefile)
     if (xmltree->saveXMLfile(savefile))
         Log("Session data saved to " + savefile);
     else
-        Log("Failed to save session data to " + savefile, true);
+        Log("Failed to save session data to " + savefile, 1);
 }
 
 
-bool Config::restoreSessionData(string sessionfile)
+bool Config::restoreSessionData(string sessionfile, bool startup)
 {
     XMLwrapper *xml = NULL;
     bool ok = false;
@@ -687,21 +678,23 @@ bool Config::restoreSessionData(string sessionfile)
         sessionfile += ".state";
     if (!sessionfile.size() || !isRegFile(sessionfile))
     {
-        Log("Session file " + sessionfile + " not available", true);
+        Log("Session file " + sessionfile + " not available", 1);
         goto end_game;
     }
     if (!(xml = new XMLwrapper(synth)))
     {
-        Log("Failed to init xmltree for restoreState", true);
+        Log("Failed to init xmltree for restoreState", 1);
         goto end_game;
     }
 
-    if (xml->loadXMLfile(sessionfile) < 0)
+    if (!xml->loadXMLfile(sessionfile))
     {
         Log("Failed to load xml file " + sessionfile);
         goto end_game;
     }
-    ok = extractConfigData(xml) && extractRuntimeData(xml) && synth->getfromXML(xml);
+    ok = extractConfigData(xml); // this needs improving
+    if (!startup && ok)
+        ok = extractRuntimeData(xml) && synth->getfromXML(xml);
 
 end_game:
     if (xml)
@@ -714,15 +707,10 @@ bool Config::extractRuntimeData(XMLwrapper *xml)
 {
     if (!xml->enterbranch("RUNTIME"))
     {
-        Log("Config extractRuntimeData, no RUNTIME branch", true);
+        Log("Config extractRuntimeData, no RUNTIME branch", 1);
         return false;
     }
-    audioEngine = (audio_drivers)xml->getpar("audio_engine", DEFAULT_AUDIO, no_audio, alsa_audio);
-    audioDevice = xml->getparstr("audio_device");
-    midiEngine = (midi_drivers)xml->getpar("midi_engine", DEFAULT_MIDI, no_midi, alsa_midi);
-    midiDevice = xml->getparstr("midi_device");
-    showGui = xml->getpar("enable_gui", showGui, 0, 1);
-    showCLI = xml->getpar("enable_CLI", showCLI, 0, 1);
+// need to put current root and bank here
     nameTag = xml->getparstr("name_tag");
     CurrentXMZ = xml->getparstr("current_xmz");
     xml->exitbranch();
@@ -733,68 +721,70 @@ bool Config::extractRuntimeData(XMLwrapper *xml)
 void Config::addRuntimeXML(XMLwrapper *xml)
 {
     xml->beginbranch("RUNTIME");
-    xml->addpar("audio_engine", audioEngine);
-    xml->addparstr("audio_device", audioDevice);
-    xml->addpar("midi_engine", midiEngine);
-    xml->addparstr("midi_device", midiDevice);
-    xml->addpar("enable_gui", showGui);
-    xml->addpar("enable_CLI", showCLI);
+// need to put current root and bank here
     xml->addparstr("name_tag", nameTag);
     xml->addparstr("current_xmz", CurrentXMZ);
     xml->endbranch();
 }
 
 
-void Config::Log(string msg, bool tostderr)
+void Config::Log(string msg, char tostderr)
 {
-    if (showGui && !tostderr && consoleMenuItem)
+    if ((tostderr & 2) && hideErrors)
+        return;
+    if (showGui && !(tostderr & 1) && toConsole)
         LogList.push_back(msg);
     else
         cerr << msg << endl;
 }
 
+
 #ifndef YOSHIMI_LV2_PLUGIN
 void Config::StartupReport(MusicClient *musicClient)
 {
     Log(string(argp_program_version));
     Log("Clientname: " + musicClient->midiClientName());
-    string report = "Config: Audio: ";
+    string report = "Audio: ";
     switch (audioEngine)
     {
         case jack_audio:
             report += "jack";
             break;
+
         case alsa_audio:
             report += "alsa";
             break;
+
         default:
             report += "nada";
     }
     report += (" -> '" + audioDevice + "'");
-    Log(report);
+    Log(report, 2);
     report = "Midi: ";
     switch (midiEngine)
     {
         case jack_midi:
             report += "jack";
             break;
+
         case alsa_midi:
             report += "alsa";
             break;
+
         default:
             report += "nada";
     }
     if (!midiDevice.size())
         midiDevice = "default";
     report += (" -> '" + midiDevice + "'");
-    Log(report);
-    Log("Oscilsize: " + asString(synth->oscilsize));
-    Log("Samplerate: " + asString(synth->samplerate));
-    Log("Period size: " + asString(synth->buffersize));
+    Log(report, 2);
+    Log("Oscilsize: " + asString(synth->oscilsize), 2);
+    Log("Samplerate: " + asString(synth->samplerate), 2);
+    Log("Period size: " + asString(synth->buffersize), 2);
 }
-
 #endif
 
+
 void Config::setRtprio(int prio)
 {
     if (prio < rtprio)
@@ -826,7 +816,7 @@ bool Config::startThread(pthread_t *pth, void *(*thread_fn)(void*), void *arg,
                     {
                         Log("Failed to set SCHED_FIFO policy in thread attribute "
                                     + string(strerror(errno))
-                                    + " (" + asString(chk) + ")", true);
+                                    + " (" + asString(chk) + ")", 1);
                         schedfifo = false;
                         continue;
                     }
@@ -834,7 +824,7 @@ bool Config::startThread(pthread_t *pth, void *(*thread_fn)(void*), void *arg,
                     {
                         Log("Failed to set inherit scheduler thread attribute "
                                     + string(strerror(errno)) + " ("
-                                    + asString(chk) + ")", true);
+                                    + asString(chk) + ")", 1);
                         schedfifo = false;
                         continue;
                     }
@@ -847,7 +837,7 @@ bool Config::startThread(pthread_t *pth, void *(*thread_fn)(void*), void *arg,
                     {
                         Log("Failed to set thread priority attribute ("
                                     + asString(chk) + ")  "
-                                    + string(strerror(errno)), true);
+                                    + string(strerror(errno)), 1);
                         schedfifo = false;
                         continue;
                     }
@@ -866,21 +856,21 @@ bool Config::startThread(pthread_t *pth, void *(*thread_fn)(void*), void *arg,
                 break;
             }
             else
-                Log("Failed to set thread detach state " + asString(chk), true);
+                Log("Failed to set thread detach state " + asString(chk), 1);
             pthread_attr_destroy(&attr);
         }
         else
-            Log("Failed to initialise thread attributes " + asString(chk), true);
+            Log("Failed to initialise thread attributes " + asString(chk), 1);
 
         if (schedfifo)
         {
             Log("Failed to start thread (sched_fifo) " + asString(chk)
-                + "  " + string(strerror(errno)), true);
+                + "  " + string(strerror(errno)), 1);
             schedfifo = false;
             continue;
         }
         Log("Failed to start thread (sched_other) " + asString(chk)
-            + "  " + string(strerror(errno)), true);
+            + "  " + string(strerror(errno)), 1);
         outcome = false;
         break;
     }
@@ -900,12 +890,15 @@ void Config::signalCheck(void)
                 case JackSessionSave:
                     saveJackSession();
                     break;
+
                 case JackSessionSaveAndQuit:
                     saveJackSession();
                     runSynth = false;
                     break;
+
                 case JackSessionSaveTemplate: // not implemented
                     break;
+
                 default:
                     break;
             }
@@ -925,7 +918,7 @@ void Config::signalCheck(void)
 
 void Config::setInterruptActive(void)
 {
-    Log("Interrupt received", true);
+    Log("Interrupt received", 1);
     __sync_or_and_fetch(&sigIntActive, 0xFF);
 }
 
@@ -939,7 +932,7 @@ void Config::setLadi1Active(void)
 bool Config::restoreJsession(void)
 {
     #if defined(JACK_SESSION)
-        return restoreSessionData(jackSessionFile);
+        return restoreSessionData(jackSessionFile, false);
     #else
         return false;
     #endif
@@ -1018,6 +1011,7 @@ void Config::AntiDenormals(bool set_daz_ftz)
     #endif
 }
 
+
 /**
 SSEcapability() and AntiDenormals() draw gratefully on the work of others,
 including:
@@ -1058,8 +1052,11 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
     switch (key)
     {
         case 'N': settings->nameTag = string(arg); break;
+
         case 'l': settings->paramsLoad = string(arg); break;
+
         case 'L': settings->instrumentLoad = string(arg); break;
+
         case 'A':
             settings->configChanged = true;
             settings->audioEngine = alsa_audio;
@@ -1068,6 +1065,7 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
             else
                 settings->audioDevice = settings->alsaAudioDevice;
             break;
+
         case 'a':
             settings->configChanged = true;
             settings->midiEngine = alsa_midi;
@@ -1076,51 +1074,44 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
             else
                 settings->midiDevice = string(settings->alsaMidiDevice);
             break;
-        case 'b': // messy but I can't think of a better way :(
+
+        case 'b':
             settings->configChanged = true;
-            num = Config::string2int(string(arg));
-            if (num >= 1024)
-                num = 1024;
-            else if (num >= 512)
-                num = 512;
-            else if (num >= 256)
-                num = 256;
-            else if (num >= 128)
-                num = 128;
-            else if (num >= 64)
-                num = 64;
-            else if (num >= 32)
-                num = 32;
-            else
-                num = 16;
-            settings->Buffersize = num;
+            settings->Buffersize = Config::string2int(string(arg));
             break;
+
         case 'D':
             if (arg)
                 settings->rootDefine = string(arg);
             break;
+
         case 'c':
             settings->configChanged = true;
             settings->showCLI = false;
             break;
+
         case 'C':
             settings->configChanged = true;
             settings->showCLI = true;
             break;
+
         case 'i':
             settings->configChanged = true;
             settings->showGui = false;
             break;
+
         case 'I':
             settings->configChanged = true;
             settings->showGui = true;
             break;
+
         case 'J':
             settings->configChanged = true;
             settings->audioEngine = jack_audio;
             if (arg)
                 settings->audioDevice = string(arg);
             break;
+
         case 'j':
             settings->configChanged = true;
             settings->midiEngine = jack_midi;
@@ -1129,57 +1120,46 @@ static error_t parse_cmds (int key, char *arg, struct argp_state *state)
             else
                 settings->midiDevice = string(settings->jackMidiDevice);
             break;
+
         case 'k': settings->startJack = true; break;
+
         case 'K': settings->connectJackaudio = true; break;
+
         case 'o':
             settings->configChanged = true;
-            num = Config::string2int(string(arg));
-            if (num >= 16384)
-                num = 16384;
-            else if (num >= 8192)
-                num = 8192;
-            else if (num >= 4096)
-                num = 4096;
-            else if (num >= 2048)
-                num = 2048;
-            else if (num >= 1024)
-                num = 1024;
-            else if (num >= 512)
-                num = 512;
-            else if (num >= 256)
-                num = 256;
-            else num = 128;
-            settings->Oscilsize = num;
+            settings->Oscilsize = Config::string2int(string(arg));
             break;
+
         case 'R':
             settings->configChanged = true;
-            num = Config::string2int(string(arg));
-            if (num >= 96000)
-                num = 96000;
-            else if (num >= 48000)
-                num = 48000;
-            else
-                num = 44100;
+            num = (Config::string2int(string(arg)) / 48 ) * 48;
+            if (num < 48000 || num > 192000)
+                num = 44100; // play safe
             settings->Samplerate = num;
             break;
+
         case 'S':
             settings->restoreState = true;
             if (arg)
                 settings->StateFile = string(arg);
             break;
-        #if defined(JACK_SESSION)
-            case 'u':
-                if (arg)
-                    settings->jackSessionFile = string(arg);
-                break;
-            case 'U':
-                    if (arg)
-                        settings->jackSessionUuid = string(arg);
+
+#if defined(JACK_SESSION)
+        case 'u':
+            if (arg)
+                settings->jackSessionFile = string(arg);
             break;
-        #endif
+
+        case 'U':
+                if (arg)
+                    settings->jackSessionUuid = string(arg);
+        break;
+#endif
+
         case ARGP_KEY_ARG:
         case ARGP_KEY_END:
             break;
+
         default:
             return ARGP_ERR_UNKNOWN;
     }
@@ -1198,6 +1178,7 @@ void Config::loadCmdArgs(int argc, char **argv)
         restoreJackSession = true;
 }
 
+
 void GuiThreadMsg::processGuiMessages()
 {
     GuiThreadMsg *msg = (GuiThreadMsg *)Fl::thread_message();
@@ -1210,55 +1191,48 @@ void GuiThreadMsg::processGuiMessages()
             SynthEngine *synth = ((SynthEngine *)msg->data);
             MasterUI *guiMaster = synth->getGuiMaster();
             if(!guiMaster)
-            {
                 cerr << "Error starting Main UI!" << endl;
-            }
             else
-            {
                 guiMaster->Init(guiMaster->getSynth()->getWindowTitle().c_str());
-            }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdateMaster:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
             MasterUI *guiMaster = synth->getGuiMaster(false);
             if(guiMaster)
-            {
                 guiMaster->refresh_master_ui();
-            }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdateConfig:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
             MasterUI *guiMaster = synth->getGuiMaster(false);
             if(guiMaster)
-            {
                 guiMaster->configui->update_config(msg->index);
-            }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdatePaths:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
             MasterUI *guiMaster = synth->getGuiMaster(false);
             if(guiMaster)
-            {
                 guiMaster->updatepaths(msg->index);
-            }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdatePanel:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
             MasterUI *guiMaster = synth->getGuiMaster(false);
             if(guiMaster)
-            {
                 guiMaster->updatepanel();
-            }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdatePart:
         {
             SynthEngine *synth = ((SynthEngine *)msg->data);
@@ -1268,8 +1242,9 @@ void GuiThreadMsg::processGuiMessages()
                 guiMaster->updatepart();
                 guiMaster->updatepanel();
             }
-        }
             break;
+        }
+
         case GuiThreadMsg::UpdatePanelItem:
             if(msg->index < NUM_MIDI_PARTS && msg->data)
             {
@@ -1282,6 +1257,7 @@ void GuiThreadMsg::processGuiMessages()
                 }
             }
             break;
+
         case GuiThreadMsg::UpdatePartProgram:
             if(msg->index < NUM_MIDI_PARTS && msg->data)
             {
@@ -1294,17 +1270,17 @@ void GuiThreadMsg::processGuiMessages()
                 }
             }
             break;
+
         case GuiThreadMsg::UpdateEffects:
             if(msg->data)
             {
                 SynthEngine *synth = ((SynthEngine *)msg->data);
                 MasterUI *guiMaster = synth->getGuiMaster(false);
                 if(guiMaster)
-                {
                     guiMaster->updateeffects(msg->index);
-                }
             }
             break;
+
         case GuiThreadMsg::RegisterAudioPort:
             if(msg->data)
             {
@@ -1312,17 +1288,17 @@ void GuiThreadMsg::processGuiMessages()
                 mainRegisterAudioPort(synth, msg->index);
             }
             break;
+
         case GuiThreadMsg::UpdateBankRootDirs:
             if(msg->data)
             {
                 SynthEngine *synth = ((SynthEngine *)msg->data);
                 MasterUI *guiMaster = synth->getGuiMaster(false);
                 if(guiMaster)
-                {
                     guiMaster->updateBankRootDirs();
-                }
             }
             break;
+
         case GuiThreadMsg::RescanForBanks:
             if(msg->data)
             {
@@ -1334,6 +1310,7 @@ void GuiThreadMsg::processGuiMessages()
                 }
             }
             break;
+
         case GuiThreadMsg::RefreshCurBank:
             if(msg->data)
             {
@@ -1341,11 +1318,18 @@ void GuiThreadMsg::processGuiMessages()
                 MasterUI *guiMaster = synth->getGuiMaster(false);
                 if(guiMaster && guiMaster->bankui)
                 {
+                    if (msg->index == 1)
+                    {
+                        // special case for first synth statup
+                        guiMaster->bankui->readbankcfg();
+                        guiMaster->bankui->rescan_for_banks(false);
+                    }
                     guiMaster->bankui->set_bank_slot();
                     guiMaster->bankui->refreshmainwindow();
                 }
             }
             break;
+
         default:
             break;
         }
