@@ -54,7 +54,7 @@ class Config : public MiscFuncs
 #endif
         void Announce(void);
         void Usage(void);
-        void Log(string msg, bool tostderr = false);
+        void Log(string msg, char tostderr = 0); // 1 = cli only ored 2 = hideable
         void flushLog(void);
 
         void clearPresetsDirlist(void);
@@ -65,9 +65,9 @@ class Config : public MiscFuncs
         void saveState() { saveSessionData(StateFile); }
         void saveState(const string statefile)  { saveSessionData(statefile); }
         bool loadState(const string statefile)
-            { return restoreSessionData(statefile); }
+            { return restoreSessionData(statefile, false); }
         bool stateRestore(void)
-            { return restoreSessionData(StateFile); }
+            { return restoreSessionData(StateFile, false); }
         bool restoreJsession(void);
         void setJackSessionSave(int event_type, string session_file);
 
@@ -79,8 +79,6 @@ class Config : public MiscFuncs
         bool startThread(pthread_t *pth, void *(*thread_fn)(void*), void *arg,
                          bool schedfifo, char lowprio, bool create_detached = true);
 
-        string addParamHistory(string file);
-        string historyFilename(int index);
         bool showQuestionOrCmdWarning(string guiQuestion, string cmdLineWarning, bool bForceCmdLinePositive);
         string programCmd(void) { return programcommand; }
 
@@ -92,6 +90,7 @@ class Config : public MiscFuncs
         string        instrumentLoad;
         string        rootDefine;
         bool          restoreState;
+        bool          stateChanged;
         string        StateFile;
         string        CurrentXMZ;
         bool          restoreJackSession;
@@ -103,6 +102,7 @@ class Config : public MiscFuncs
 
         bool          runSynth;
         bool          showGui;
+        bool          showSplash;
         bool          showCLI;
         int           VirKeybLayout;
 
@@ -114,7 +114,7 @@ class Config : public MiscFuncs
         string        jackServer;
         string        jackMidiDevice;
         bool          startJack;        // false
-        bool          connectJackaudio; // false
+        bool          connectJackaudio;
         string        jackSessionUuid;
 
         string        alsaAudioDevice;
@@ -122,13 +122,14 @@ class Config : public MiscFuncs
         string        nameTag;
 
         unsigned int  GzipCompression;
-        int           Interpolation;        
+        int           Interpolation;
         string        presetsDirlist[MAX_PRESETS];
         int           checksynthengines;
         bool          SimpleCheck;
         int           xmlType;
         int           EnableProgChange;
-        bool          consoleMenuItem;
+        bool          toConsole;
+        bool          hideErrors;
         bool          logXMLheaders;
         bool          configChanged;
         int           rtprio;
@@ -136,6 +137,7 @@ class Config : public MiscFuncs
         int           midi_bank_C;
         int           midi_upper_voice_C;
         int           enable_part_on_voice_load;
+        bool          ignoreResetCCs;
         bool          monitorCCin;
         int           single_row_panel;
         int           NumAvailableParts;
@@ -161,29 +163,26 @@ class Config : public MiscFuncs
             int Controller;
             bool vectorEnabled[NUM_MIDI_CHANNELS];
         };
-        
-        IOdata nrpndata;        
-        
-        deque<HistoryListItem> ParamsHistory;
-        deque<HistoryListItem>::iterator itx;
-        static const unsigned short MaxParamsHistory;
+
+        IOdata nrpndata;
+
         list<string> LogList;
         BodyDisposal *deadObjects;
 
     private:
         void loadCmdArgs(int argc, char **argv);
         bool loadConfig(void);
+        void defaultPresets(void);
         bool extractConfigData(XMLwrapper *xml);
         bool extractRuntimeData(XMLwrapper *xml);
         void addConfigXML(XMLwrapper *xml);
         void addRuntimeXML(XMLwrapper *xml);
         void saveSessionData(string savefile);
-        bool restoreSessionData(string sessionfile);
+        bool restoreSessionData(string sessionfile, bool startup);
         int SSEcapability(void);
         void AntiDenormals(bool set_daz_ftz);
         void saveJackSession(void);
 
-        unsigned short nextHistoryIndex;
         int sigIntActive;
         int ladi1IntActive;
         int sse_level;
@@ -197,6 +196,7 @@ class Config : public MiscFuncs
         friend class YoshimiLV2Plugin;
 };
 
+
 //struct GuiThreadMsg must be allocated by caller via `new` and is freed by receiver via `delete`
 class GuiThreadMsg
 {
