@@ -120,7 +120,6 @@ void Part::defaults(void)
     Penabled = 0;
     Pminkey = 0;
     Pmaxkey = 127;
-//    Pnoteon = 1;
     Ppolymode = 1;
     Plegatomode = 0;
     setVolume(96);
@@ -136,6 +135,7 @@ void Part::defaults(void)
     ctl->defaults();
 }
 
+
 void Part::defaultsinstrument(void)
 {
     Pname = "Simple Sound";
@@ -341,7 +341,8 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
         // start the note
         partnote[pos].status = KEY_PLAYING;
         partnote[pos].note = note;
-        if (legatomodevalid) {
+        if (legatomodevalid)
+        {
             partnote[posb].status = KEY_PLAYING;
             partnote[posb].note = note;
         }
@@ -593,7 +594,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
                     if (kit[item].adpars && kit[item].Padenabled)
                     {
                         partnote[posb].kititem[ci].adnote =
-                            new ADnote(kit[item].adpars, ctl, notebasefreq, 
+                            new ADnote(kit[item].adpars, ctl, notebasefreq,
                                         vel, portamento, note, true, synth); // silent
                     }
                     if (kit[item].subpars && kit[item].Psubenabled)
@@ -625,6 +626,7 @@ void Part::NoteOn(int note, int velocity, int masterkeyshift)
     setkeylimit(Pkeylimit);
 }
 
+
 // Note Off Messages
 void Part::NoteOff(int note) //relase the key
 {
@@ -662,47 +664,60 @@ void Part::SetController(unsigned int type, int par)
         case C_pitchwheel:
             ctl->setpitchwheel(par);
             break;
+
         case C_expression:
             ctl->setexpression(par);
             setVolume(Pvolume);
             break;
+
         case C_portamento:
             ctl->setportamento(par);
             break;
+
         case C_panning:
             par = 64 + (par - 64) * (ctl->panning.depth / 64.0); // force float during calculation
             setPan(par);
             break;
+
         case C_filtercutoff:
             ctl->setfiltercutoff(par);
             break;
+
         case C_filterq:
             ctl->setfilterq(par);
             break;
+
         case C_bandwidth:
             ctl->setbandwidth(par);
             break;
+
         case C_modwheel:
             ctl->setmodwheel(par);
             break;
+
         case C_fmamp:
             ctl->setfmamp(par);
             break;
+
         case C_volume:
             if (ctl->volume.receive)
                 setVolume(par * ctl->volume.volume);
             break;
+
         case C_sustain:
             ctl->setsustain(par);
             if (!ctl->sustain.sustain)
                 RelaseSustainedKeys();
             break;
+
         case C_legatofootswitch:
             ctl->setlegato(par);
             break;
+
         case C_allsoundsoff:
             AllNotesOff(); // Panic
             break;
+
         case C_resetallcontrollers:
             ctl->resetall();
             RelaseSustainedKeys();
@@ -718,9 +733,11 @@ void Part::SetController(unsigned int type, int par)
             }
             // more update to add here if I add controllers
             break;
+
         case C_allnotesoff:
             RelaseAllKeys();
             break;
+
         case C_resonance_center:
             ctl->setresonancecenter(par);
             for (int item = 0; item < NUM_KIT_ITEMS; ++item)
@@ -731,6 +748,7 @@ void Part::SetController(unsigned int type, int par)
                                                                   ctl->resonancecenter.relcenter);
             }
             break;
+
         case C_resonance_bandwidth:
             ctl->setresonancebw(par);
             kit[0].adpars->GlobalPar.Reson->sendcontroller(C_resonance_bandwidth,
@@ -1033,6 +1051,7 @@ void Part::setVolume(float value)
     volume  = dB2rap((value - 96.0f) / 96.0f * 40.0f) * ctl->expression.relvolume;
 }
 
+
 void Part::setDestination(int value)
 {
     Paudiodest = value;
@@ -1355,7 +1374,7 @@ void Part::getfromXML(XMLwrapper *xml)
 
     Pminkey = xml->getpar127("min_key", Pminkey);
     Pmaxkey = xml->getpar127("max_key", Pmaxkey);
-    Pkeyshift = xml->getpar127("key_shift", Pkeyshift);
+    Pkeyshift = xml->getpar("key_shift", Pkeyshift, MIN_KEY_SHIFT + 64, MAX_KEY_SHIFT + 64);
     Prcvchn = xml->getpar127("rcv_chn", Prcvchn);
 
     Pvelsns = xml->getpar127("velocity_sensing", Pvelsns);
@@ -1379,7 +1398,7 @@ void Part::getfromXML(XMLwrapper *xml)
     if (Pfrand > 50)
         Pfrand = 50;
     setDestination(xml->getpar127("destination", Paudiodest));
-    
+
     if (xml->enterbranch("INSTRUMENT"))
     {
         getfromXMLinstrument(xml);
