@@ -58,13 +58,20 @@ XMLwrapper::XMLwrapper(SynthEngine *_synth) :
     memset(&parentstack, 0, sizeof(parentstack));
     tree = mxmlNewElement(MXML_NO_PARENT, "?xml version=\"1.0\" encoding=\"UTF-8\"?");
     mxml_node_t *doctype = mxmlNewElement(tree, "!DOCTYPE");
-    mxmlElementSetAttr(doctype, "ZynAddSubFX-data", NULL);
 
-    node = root = mxmlNewElement(tree, "ZynAddSubFX-data");
-
-    mxmlElementSetAttr(root, "version-major", "2");
-    mxmlElementSetAttr(root, "version-minor", "5");
-    mxmlElementSetAttr(root, "ZynAddSubFX-author", "Nasca Octavian Paul");
+    if (synth->getRuntime().xmlType <= XML_PRESETS)
+    {
+        mxmlElementSetAttr(doctype, "ZynAddSubFX-data", NULL);
+        node = root = mxmlNewElement(tree, "ZynAddSubFX-data");
+        mxmlElementSetAttr(root, "version-major", "2");
+        mxmlElementSetAttr(root, "version-minor", "5");
+        mxmlElementSetAttr(root, "ZynAddSubFX-author", "Nasca Octavian Paul");
+    }
+    else
+    {
+    mxmlElementSetAttr(doctype, "Yoshimi-data", NULL);
+    node = root = mxmlNewElement(tree, "Yoshimi-data");
+    }
 
     mxmlElementSetAttr(root, "Yoshimi-author", "Alan Ernest Calvert");
     string tmp = YOSHIMI_VERSION;
@@ -74,16 +81,20 @@ XMLwrapper::XMLwrapper(SynthEngine *_synth) :
     mxmlElementSetAttr(root, "Yoshimi-minor", tmp.substr(pos1+1, pos2-pos1-1).c_str());
 
     info = addparams0("INFORMATION"); // specifications
-    beginbranch("BASE_PARAMETERS");
-    addpar("max_midi_parts", synth->getRuntime().NumAvailableParts);
-    addpar("max_kit_items_per_instrument", NUM_KIT_ITEMS);
 
-    addpar("max_system_effects", NUM_SYS_EFX);
-    addpar("max_insertion_effects", NUM_INS_EFX);
-    addpar("max_instrument_effects", NUM_PART_EFX);
+    if (synth->getRuntime().xmlType <= XML_CONFIG)
+    {
+        beginbranch("BASE_PARAMETERS");
+            addpar("max_midi_parts", synth->getRuntime().NumAvailableParts);
+            addpar("max_kit_items_per_instrument", NUM_KIT_ITEMS);
 
-    addpar("max_addsynth_voices", NUM_VOICES);
-    endbranch();
+            addpar("max_system_effects", NUM_SYS_EFX);
+            addpar("max_insertion_effects", NUM_INS_EFX);
+            addpar("max_instrument_effects", NUM_PART_EFX);
+
+            addpar("max_addsynth_voices", NUM_VOICES);
+        endbranch();
+    }
 }
 
 
@@ -105,7 +116,7 @@ bool XMLwrapper::checkfileinformation(const string& filename)
     char *xmldata = doloadfile(filename);
     if (!xmldata)
         return -1;
-    
+
     bool bRet = false; // we're not actually using this!
     char *start = strstr(xmldata, "<INFORMATION>");
     char *end = strstr(xmldata, "</INFORMATION>");
@@ -121,7 +132,7 @@ bool XMLwrapper::checkfileinformation(const string& filename)
     char *idx = start;
     *end = 0; // fiddle to limit search - I can't find a better way :(
     unsigned short names = 0;
-    
+
     /* the following could be in any order. We are checking for
      * the actual exisitence of the fields as well as their value.
      */
@@ -132,7 +143,7 @@ bool XMLwrapper::checkfileinformation(const string& filename)
         if(strstr(idx, "name=\"ADDsynth_used\" value=\"yes\""))
             information.ADDsynth_used = 1;
     }
-    
+
     idx = strstr(start, "name=\"SUBsynth_used\"");
     if (idx != NULL)
     {
@@ -140,7 +151,7 @@ bool XMLwrapper::checkfileinformation(const string& filename)
         if(strstr(idx, "name=\"SUBsynth_used\" value=\"yes\""))
             information.SUBsynth_used = 1;
     }
-    
+
     idx = strstr(start, "name=\"PADsynth_used\"");
     if (idx != NULL)
     {
@@ -148,7 +159,7 @@ bool XMLwrapper::checkfileinformation(const string& filename)
         if(strstr(idx, "name=\"PADsynth_used\" value=\"yes\""))
             information.PADsynth_used = 1;
     }
-    
+
     if (names == 7)
     {
         bRet = true;
@@ -170,10 +181,10 @@ bool XMLwrapper::slowinfosearch(char *idx)
     idx = strstr(idx, "<INSTRUMENT_KIT>");
     if (idx == NULL)
         return false;
-    
+
     string mark;
     int max = NUM_KIT_ITEMS;
-    
+
     /*
      * The following *must* exist, otherwise the file is corrupted.
      * They will always be in this order, which means we only need
@@ -193,13 +204,13 @@ bool XMLwrapper::slowinfosearch(char *idx)
         idx = strstr(idx, mark.c_str());
         if (idx == NULL)
             return false;
-        
+
         idx = strstr(idx, "name=\"enabled\"");
         if (idx == NULL)
             return false;
         if (!strstr(idx, "name=\"enabled\" value=\"yes\""))
             continue;
-        
+
         if (!information.ADDsynth_used)
         {
             idx = strstr(idx, "name=\"add_enabled\"");
@@ -241,6 +252,7 @@ bool XMLwrapper::slowinfosearch(char *idx)
 bool XMLwrapper::saveXMLfile(const string& filename)
 {
     char *xmldata = getXMLdata();
+
     if (!xmldata)
     {
         synth->getRuntime().Log("XML: Failed to allocate xml data space");
@@ -286,34 +298,47 @@ char *XMLwrapper::getXMLdata()
     memset(tabs, 0, STACKSIZE + 2);
     mxml_node_t *oldnode=node;
     node = info;
+
     switch (synth->getRuntime().xmlType)
     {
         case 0:
             addparstr("XMLtype", "Invalid");
             break;
+
         case XML_INSTRUMENT:
             addparbool("ADDsynth_used", information.ADDsynth_used);
             addparbool("SUBsynth_used", information.SUBsynth_used);
             addparbool("PADsynth_used", information.PADsynth_used);
             break;
+
         case XML_PARAMETERS:
             addparstr("XMLtype", "Parameters");
             break;
+
         case XML_MICROTONAL:
             addparstr("XMLtype", "Scales");
             break;
+
         case XML_PRESETS:
             addparstr("XMLtype", "Presets");
             break;
+
         case XML_STATE:
             addparstr("XMLtype", "Session");
             break;
+
         case XML_CONFIG:
             addparstr("XMLtype", "Config");
             break;
+
         case XML_BANK:
             addparstr("XMLtype", "Roots and Banks");
             break;
+
+        case XML_HISTORY:
+            addparstr("XMLtype", "Recent Files");
+            break;
+
         default:
             addparstr("XMLtype", "Unknown");
             break;
@@ -374,10 +399,11 @@ void XMLwrapper::endbranch()
 
 
 // LOAD XML members
-
 bool XMLwrapper::loadXMLfile(const string& filename)
 {
+    bool zynfile = true;
     bool yoshitoo = false;
+
     if (tree)
         mxmlDelete(tree);
     tree = NULL;
@@ -396,15 +422,25 @@ bool XMLwrapper::loadXMLfile(const string& filename)
         synth->getRuntime().Log("XML: File " + filename + " is not XML");
         return false;
     }
-    node = root = mxmlFindElement(tree, tree, "ZynAddSubFX-data", NULL, NULL, MXML_DESCEND);
+    root = mxmlFindElement(tree, tree, "ZynAddSubFX-data", NULL, NULL, MXML_DESCEND);
+    if (!root)
+    {
+        zynfile = false;
+        root = mxmlFindElement(tree, tree, "Yoshimi-data", NULL, NULL, MXML_DESCEND);
+    }
+
     if (!root)
     {
         synth->getRuntime().Log("XML: File " + filename + " doesn't contain valid data in this context");
         return false;
     }
+    node = root;
     push(root);
-    xml_version.major = string2int(mxmlElementGetAttr(root, "version-major"));
-    xml_version.minor = string2int(mxmlElementGetAttr(root, "version-minor"));
+    if (zynfile)
+    {
+        xml_version.major = string2int(mxmlElementGetAttr(root, "version-major"));
+        xml_version.minor = string2int(mxmlElementGetAttr(root, "version-minor"));
+    }
     if (mxmlElementGetAttr(root, "Yoshimi-major"))
     {
         xml_version.y_major = string2int(mxmlElementGetAttr(root, "Yoshimi-major"));
@@ -418,7 +454,8 @@ bool XMLwrapper::loadXMLfile(const string& filename)
     }
     if (synth->getRuntime().logXMLheaders)
     {
-        synth->getRuntime().Log("ZynAddSubFX version major " + asString(xml_version.major) + "   minor " + asString(xml_version.minor));
+        if (zynfile)
+            synth->getRuntime().Log("ZynAddSubFX version major " + asString(xml_version.major) + "   minor " + asString(xml_version.minor));
         if (yoshitoo)
             synth->getRuntime().Log("Yoshimi version major " + asString(xml_version.y_major) + "   minor " + asString(xml_version.y_minor));
     }
@@ -468,9 +505,6 @@ char *XMLwrapper::doloadfile(const string& filename)
             }
             quit = true;
         }
-        //this call makes yoshimi crash sometimes
-        // comment it out - code in main.cpp already does this
-        //synth->getRuntime().signalCheck();
     }
     gzclose(gzf);
     return xmldata;
@@ -555,6 +589,12 @@ int XMLwrapper::getpar127(const string& name, int defaultpar)
 }
 
 
+int XMLwrapper::getpar255(const string& name, int defaultpar)
+{
+    return(getpar(name, defaultpar, 0, 255));
+}
+
+
 int XMLwrapper::getparbool(const string& name, int defaultpar)
 {
     node = mxmlFindElement(peek(), peek(), "par_bool", "name", name.c_str(), MXML_DESCEND_FIRST);
