@@ -65,10 +65,11 @@ MusicClient *MusicClient::newMusicClient(SynthEngine *_synth)
     return 0;
 }
 
+
 void *MusicClient::timerThread_fn(void *arg)
 {
     MusicClient *nmc = (MusicClient *)arg;
-    useconds_t sleepInterval = (useconds_t)(1000000.0f * (double)nmc->synth->getRuntime().Buffersize / (double)NMC_SRATE);
+    useconds_t sleepInterval = (useconds_t)(1000000.0f * (double)nmc->synth->getRuntime().Buffersize / nmc->synth->getRuntime().Samplerate);//(double)NMC_SRATE);
     nmc->timerWorking = true;
     while(nmc->timerWorking)
     {
@@ -78,11 +79,12 @@ void *MusicClient::timerThread_fn(void *arg)
     return 0;
 }
 
+
 MusicClient::MusicClient(SynthEngine *_synth, audio_drivers _audioDrv, midi_drivers _midiDrv)
     :synth(_synth), timerThreadId(0), timerWorking(false),
     audioDrv(_audioDrv), midiDrv(_midiDrv), audioIO(0), midiIO(0)
 {
-    synth->getRuntime().Samplerate = NMC_SRATE;
+    //synth->getRuntime().Samplerate = NMC_SRATE;
 
     for(int i = 0; i < NUM_MIDI_PARTS + 1; i++)
     {
@@ -100,26 +102,31 @@ MusicClient::MusicClient(SynthEngine *_synth, audio_drivers _audioDrv, midi_driv
 
     switch(audioDrv)
     {
-    case jack_audio:
-        audioIO = new JackEngine(synth);
-        break;
-    case alsa_audio:
-        audioIO = new AlsaEngine(synth);
-        break;
-    default:
-        break;
+        case jack_audio:
+            audioIO = new JackEngine(synth);
+            break;
+
+        case alsa_audio:
+            audioIO = new AlsaEngine(synth);
+            break;
+
+        default:
+            break;
     }
 
     switch(midiDrv)
     {
-    case jack_midi:
-        midiIO = new JackEngine(synth);
-        break;
-    case alsa_midi:
-        midiIO = new AlsaEngine(synth);
-        break;
-    default:
-        break;
+        case jack_midi:
+            if (audioDrv != jack_audio)
+                midiIO = new JackEngine(synth);
+            break;
+
+        case alsa_midi:
+            midiIO = new AlsaEngine(synth);
+            break;
+
+        default:
+            break;
     }
 
     if(audioDrv != no_audio)
@@ -131,13 +138,14 @@ MusicClient::MusicClient(SynthEngine *_synth, audio_drivers _audioDrv, midi_driv
     }
     if(midiDrv != no_midi)
     {
-        if(!midiIO)
+        if(!midiIO && audioDrv != jack_audio)
         {
             abort();
         }
     }
 }
 
+
 MusicClient::~MusicClient()
 {
     Close();
@@ -160,6 +168,7 @@ MusicClient::~MusicClient()
     }
 }
 
+
 bool MusicClient::Open()
 {
     bool bAudio = true;
@@ -172,6 +181,10 @@ bool MusicClient::Open()
     {
         bMidi = midiIO->openMidi();
     }
+    else if (audioDrv == jack_audio)
+    {
+        bMidi = audioIO->openMidi();
+    }
     if(bAudio && bMidi)
     {
         synth->getRuntime().audioEngine = audioDrv;
@@ -181,6 +194,7 @@ bool MusicClient::Open()
     return bAudio && bMidi;
 }
 
+
 bool MusicClient::Start()
 {
     bool bAudio = true;
@@ -207,6 +221,7 @@ bool MusicClient::Start()
     return bAudio && bMidi;
 }
 
+
 void MusicClient::Close()
 {
     if(midiIO)
@@ -229,6 +244,7 @@ void MusicClient::Close()
     }
 }
 
+
 unsigned int MusicClient::getSamplerate()
 {
     if(audioIO)
@@ -238,6 +254,7 @@ unsigned int MusicClient::getSamplerate()
     return NMC_SRATE;
 }
 
+
 int MusicClient::getBuffersize()
 {
     if(audioIO)
@@ -248,6 +265,7 @@ int MusicClient::getBuffersize()
     return synth->getRuntime().Buffersize;
 }
 
+
 string MusicClient::audioClientName()
 {
     if(audioIO)
@@ -258,6 +276,7 @@ string MusicClient::audioClientName()
     return "null_audio";
 }
 
+
 string MusicClient::midiClientName()
 {
     if(midiIO)
@@ -267,6 +286,7 @@ string MusicClient::midiClientName()
     return "null_midi";
 }
 
+
 int MusicClient::audioClientId()
 {
     if(audioIO)
@@ -277,6 +297,7 @@ int MusicClient::audioClientId()
 
 }
 
+
 int MusicClient::midiClientId()
 {
     if(midiIO)
@@ -287,6 +308,7 @@ int MusicClient::midiClientId()
 
 }
 
+
 void MusicClient::registerAudioPort(int portnum)
 {
     if(audioIO)
