@@ -118,12 +118,12 @@ static void *mainGuiThread(void *arg)
 #else
     Fl_PNG_Image pix("yoshimi_logo_png", yoshimi_logo_png, sizeof(yoshimi_logo_png));
 #endif
-    
+
     const int splashWidth = 411;
     const int splashHeight = 311;
     const int textHeight = 20;
     const int textBorder = 15;
-    
+
     Fl_Window winSplash(splashWidth, splashHeight, "yoshimi splash screen");
     Fl_Box box(0, 0, splashWidth,splashHeight);
     //Fl_Pixmap pix(yoshimi_logo);
@@ -135,19 +135,19 @@ static void *mainGuiThread(void *arg)
     boxLb.labelsize(textHeight);
     boxLb.labeltype(FL_NORMAL_LABEL);
     boxLb.labelfont(FL_HELVETICA | FL_ITALIC);
-    boxLb.label("Yoshimi is starting up");
+    string startup = YOSHIMI_VERSION;
+    startup = "Yoshimi " + startup + " is starting";
+    boxLb.label(startup.c_str());
 
-    winSplash.set_non_modal();
+    winSplash.set_modal();
     winSplash.clear_border();
     winSplash.border(false);
 
-    if (bShowGui)
+    if (bShowGui && firstRuntime->showSplash)
     {
-        //o->Rectangle::set(Fl_Monitor::find(0,0),o->w(),o->h(),fltk::ALIGN_CENTER);
         winSplash.position((Fl::w() - winSplash.w()) / 2, (Fl::h() - winSplash.h()) / 2);
         winSplash.show();
-        Fl::add_timeout(2.5, splashTimeout, &winSplash);
-
+        Fl::add_timeout(2, splashTimeout, &winSplash);
     }
 
     do
@@ -164,12 +164,12 @@ static void *mainGuiThread(void *arg)
         else
             usleep(33333);
     }
-    while (firstSynth == NULL);
+    while (firstSynth == NULL); // just wait
 
     GuiThreadMsg::sendMessage(firstSynth, GuiThreadMsg::NewSynthEngine, 0);
 
     while (firstSynth->getRuntime().runSynth)
-    {        
+    {
         if (firstSynth->getUniqueId() == 0)
         {
             firstSynth->getRuntime().signalCheck();
@@ -229,6 +229,7 @@ static void *mainGuiThread(void *arg)
         else
             usleep(33333);
     }
+    firstSynth->saveHistory();
     firstSynth->saveBanks(0);
     return NULL;
 }
@@ -276,7 +277,7 @@ bool mainCreateNewInstance(unsigned int forceId)
     if (synth->getRuntime().showGui)
     {
         synth->setWindowTitle(musicClient->midiClientName());
-        if(firstSynth != NULL) //FLTK is not ready yet - send this messege leter for first synth
+        if(firstSynth != NULL) //FLTK is not ready yet - send this message later for first synth
         {
             GuiThreadMsg::sendMessage(synth, GuiThreadMsg::NewSynthEngine, 0);
         }
@@ -287,8 +288,12 @@ bool mainCreateNewInstance(unsigned int forceId)
     if (synth->getUniqueId() == 0)
         cout << "\nYay! We're up and running :-)\n";
     else
+    {
         cout << "\nStarted "<< synth->getUniqueId() << "\n";
-    synthInstances.insert(std::make_pair<SynthEngine *, MusicClient *>(synth, musicClient));
+        // following copied here for other instances
+        synth->installBanks(synth->getUniqueId());
+    }
+    synthInstances.insert(std::make_pair(synth, musicClient));
     //register jack ports for enabled parts
     for (int npart = 0; npart < NUM_MIDI_PARTS; ++npart)
     {
@@ -297,9 +302,6 @@ bool mainCreateNewInstance(unsigned int forceId)
             mainRegisterAudioPort(synth, npart);
         }
     }
-    
-    synth->installBanks(synth->getUniqueId());
-    
     return true;
 
 bail_out:
@@ -329,11 +331,11 @@ int main(int argc, char *argv[])
 {
     struct termios  oldTerm;
     tcgetattr(0, &oldTerm);
-    
-    cout << "Yoshimi is starting" << endl; // guaranteed start message
+
+    cout << "Yoshimi " << YOSHIMI_VERSION << " is starting" << endl; // guaranteed start message
     globalArgc = argc;
     globalArgv = argv;
-    bool bExitSuccess = false;    
+    bool bExitSuccess = false;
     map<SynthEngine *, MusicClient *>::iterator it;
     bool guiStarted = false;
     pthread_t thr;
@@ -371,7 +373,7 @@ int main(int argc, char *argv[])
     }
 
     if (!guiStarted)
-    {        
+    {
         cout << "Yoshimi can't start main gui loop!" << endl;
         goto bail_out;
     }
@@ -390,11 +392,14 @@ int main(int argc, char *argv[])
         firstSynth->getRuntime().Log("Setting SIGTERM handler failed");
     if (sigaction(SIGQUIT, &yoshimiSigAction, NULL))
         firstSynth->getRuntime().Log("Setting SIGQUIT handler failed");
+    // following moved here for faster first synth startup
+    firstSynth->loadHistory();
+    firstSynth->installBanks(0);
+    GuiThreadMsg::sendMessage(firstSynth, GuiThreadMsg::RefreshCurBank, 1);
 
-    splashMessages.push_back("Startup complete!");
+    //splashMessages.push_back("Startup complete!");
 
     //create command line processing thread
-
     pthread_t cmdThr;
     if(bShowCmdLine)
     {
@@ -409,7 +414,7 @@ int main(int argc, char *argv[])
     }
 
     void *ret;
-    pthread_join(thr, &ret);    
+    pthread_join(thr, &ret);
     if(ret == (void *)1)
     {
         goto bail_out;
